# Speedcord
![GitHub last commit](https://img.shields.io/github/last-commit/tag-epic/speedcord)
![GitHub issues](https://img.shields.io/github/issues-raw/tag-epic/speedcord)
![GitHub pull requests](https://img.shields.io/github/issues-pr/tag-epic/speedcord)
![PyPI downloads](https://img.shields.io/pypi/dm/speedcord)  
A simple discord API wrapper - without all the bullshit

We have a discord! Join us at https://discord.gg/yxrprWz  
If you liked the library, feel free to leave a star!  
